/* 
 * CSE142, Spring 1999
 * Homework 4

  STARTER PROGRAM

  Modified by:
  Francie Zant
  Section AD
  CSE 142, Spring 1999

 * Traffic animation, pig animation program
 *
 */


#include "gp142.h"
#include <stdio.h>
#include <math.h>

#include <time.h>
	/* 
	* <time.h> is included so the current time can be accessed
	* to initialize the random number generator.  If you don't
	* use random numbers (and you don't have to) you can either
	* ignore this #include or delete it.
	*/

/* Logical constants */
#define TRUE    		1
#define FALSE   		0

/* 
 * For many of the GP142 functions, a line width of
 * zero means to fill the shape being drawn.  The
 * constant FILL is used in function calls when a solid
 * shape is desired.
 */
#define FILL 0


/*
 * Symbolic constants.  Change as needed.
 */

/* Menu buttons: */

/* Top-left coordinates of button palette */
#define MENU_TOP		(GP142_YMAX - 5)
#define MENU_LEFT		(-GP142_XMAX + 5)

/* Height and width of buttons in pixels */
#define BUTTON_HEIGHT  	25
#define BUTTON_WIDTH 	75

/* Number of buttons */
#define NUM_BUTTONS 	7


/* Possible locations of mouse clicks: */

/*   Mouse click in some button */
#define BUTTON_CLICK 1

/*   Mouse click elsewhere */
#define OTHER_CLICK 0


/* Coordinates of objects in the drawing */

/* y-coordinate of the top of the ground in the landscape */
#define HORIZON 0

/* Vertical center and width of highway */
#define HIGHWAY_CENTER ((-GP142_YMAX + HORIZON) / 2)
#define HIGHWAY_WIDTH  30

/* Width of Crosswalk */
#define XWALK_WIDTH 35

/* Maximum number of vehicles that can appear in the animation */
#define MAX_CARS	4

/* Height and width of a single car */
#define CAR_HEIGHT 26
#define CAR_WIDTH  60


/*****************************************************************************

     FUNCTION PROTOTYPES

*****************************************************************************/

/* Initialize random number generator.  [Ignore or		*/
/* remove if your program doesn't use random numbers.]	*/
void initialize_random_numbers();

/* Draw the background, including the sun at coordinates sun_x and sun_y */
void draw_landscape(int sun_x, int sun_y);

/* Draw the buttons */
void draw_buttons();

/* Return kind of mouse click (in a button, etc.) */
int  classify_mouse_click(int mouse_x, int mouse_y);

/* Process button click at location x, y.  Update pig location, 
 * car speed, direction, color, and whether traffic is moving 
 * as needed. */
void handle_button(int x, int y, int *traffic_moving, int *car_speed,
				   int car_direction[], int car_color[], int *freepiggy);

/* Update sun coordinates sun_x, sun_y for one tick */
void move_sun(int *sun_x, int *sun_y);

/* Update all vehicle x, y coordinates, given current x, y */
/* location, direction (+1 or -1), and speed in pixels per tick. */
void move_traffic(int x[], int y[], int direction[], int speed);

/* Draw all vehicles given their current x, y coordinates and color */
void draw_traffic(int x[], int y[], int color[]);

/* Draw a single car of the given color with horizontal */
/* center x and bottom y*/
void draw_car(int x[], int y[], int color[]);

/* Display error message if internal error is detected. */
void something_is_wrong (void);

/* Draw the pig from current (x, y) position of center of head
 * according to pig_time */
void Draw_piggy(int x, int y, int pig_time);

/* Move the piggy according to pig_time */
void Move_piggy(int *pig_x, int *pig_y, int *pig_time, int *freepiggy);


/*****************************************************************************

     MAIN

*****************************************************************************/

/*
 * Main program contents:
 *   - Major program variables that persist throughout execution
 *   - Event loop that processes GP142 events until the user quits,
 *     and updates variables and redraws the window as needed.
 */
int main(void)
{
	/* Event handling and buttons: */
	int  quit;				/* = "user has selected quit"				*/
	int  event;				/* the most recent GP142 event				*/
	char key_pressed;		/* last keyboard character from key event	*/
	int  mouse_x, mouse_y;	/* x and y coordinates of latest mouse event*/
	int  click_kind;		/* kind of mouse click (button, etc.)		*/

	/* Information about the piggy */
	int pig_x, pig_y;		/* x, y coordinates of pig head center */
	int freepiggy;			/* set to true if pig is being animated */
	int pig_time;			/* tracks progress of pig along path when
							 * animated by free piggy button */

	/* Information about the sun: */
	int sun_x, sun_y;			/* screen x and y coordinates */

	/* Information about vehicles in the animation:*/
	int car_x[MAX_CARS], car_y[MAX_CARS];/* current position of the cars */
	int car_direction[MAX_CARS]; /* current direction: +1=right, -1=left */
	int car_color[MAX_CARS]; /* color of the car */
	int car_speed; /* speed in pixels per tick when traffic moving */	
	int traffic_moving; /* = "traffic is currently moving" */
	

	initialize_random_numbers();
	
	/* Initialize graphics package, clear the window,	*/
	/* turn logging off, and start animation.			*/
	GP142_open();
	GP142_logging(LOG_OFF);
	GP142_clear();
	GP142_animate(ANI_RUN);

	/* set initial location of the sun */
	sun_x = GP142_XMAX - 50;
	sun_y = GP142_YMAX - 35;

	/* set initial conditions for piggy */
	pig_x = -GP142_XMAX + 120;
	pig_y = HIGHWAY_CENTER / 3;
	freepiggy = FALSE;
	pig_time = 0;

	/* set initial conditions for the cars */
	car_x[0] = -GP142_XMAX / 2;
	car_x[1] = GP142_XMAX / 2;
	car_x[2] = car_x[0];
	car_x[3] = car_x[1];
	car_y[0] = HIGHWAY_CENTER;
	car_y[1] = HIGHWAY_CENTER;
	car_y[2] = HIGHWAY_CENTER - HIGHWAY_WIDTH;
	car_y[3] = car_y[2];
	car_direction[0] = -1;
	car_direction[1] = -1;
	car_direction[2] = 1;
	car_direction[3] = 1;
	car_speed = 5;
	car_color[0] = RED;
	car_color[1] = BLUE;
	car_color[2] = YELLOW;
	car_color[3] = PURPLE;
	traffic_moving = TRUE;
	
	/* Draw initial landscape, buttons, traffic, and pig */
	draw_landscape(sun_x,sun_y);
	draw_buttons( );
	draw_traffic(car_x, car_y, car_color);
	Draw_piggy(pig_x, pig_y, pig_time);
	

	/*
	 * Main event loop:
	 * ---- ----- -----
	 * Wait for the next user action, decode it, and call an
	 * appropriate function to handle it.  Repeat until the
	 * user selects quit.
	 */
	quit = FALSE;
	while (!quit) {
		
		/* get next event */
		event = GP142_await_event(&mouse_x, &mouse_y, &key_pressed);
		
		/* perform appropriate action depending on kind of event */
		switch (event) {
		case GP142_QUIT:
			/* Quit selected */
			quit = TRUE;
			break;
			
		case GP142_KBD:
			/* Key pressed.  Not used now.  If the program should		*/
			/* react to keyboard events, insert something appropriate	*/
			/* here.  Note that scanf CANNOT be used with GP142.		*/
			break;
			
		case GP142_MOUSE:
			/* Mouse click.  Determine if in a menu button	*/
			/* or elsewhere and process accordingly.		*/
			click_kind = classify_mouse_click(mouse_x, mouse_y);
			if (click_kind == BUTTON_CLICK) {
				handle_button(mouse_x, mouse_y, &traffic_moving, &car_speed,
								car_direction, car_color, &freepiggy);
			} else {
				/* insert code here (and additional else-if statements) */
				/* to react to mouse clicks elsewhere on the screen */
			}
			break;
			
		case GP142_PERIODIC:
			/* Timer interval event.  Update everything	*/
			/* that needs to change as time advances.	*/
			move_sun(&sun_x, &sun_y);
			if (traffic_moving)
				move_traffic(car_x, car_y, car_direction, car_speed);
			if (freepiggy)
				Move_piggy(&pig_x, &pig_y, &pig_time, &freepiggy);
			break;
			
		default:
			/* unknown event */
			break;
			
		}  /*end switch */
		
		/* Redraw everything */
		draw_landscape(sun_x, sun_y);
		draw_buttons();
		draw_traffic(car_x, car_y, car_color);
		Draw_piggy(pig_x, pig_y, pig_time);
		
	}  /* end event loop */
	
	
	/* Termination: shut down graphics window and exit */
	GP142_close();
	return 0;
}  /*end main */


/*****************************************************************************

     BACKGROUND LANDSCAPE

*****************************************************************************/


/* Draw the background, including the sun at coordinates sun_x and sun_y */
void draw_landscape(int sun_x, int sun_y)
{
	int text_offset = -GP142_XMAX + 15;	/* horizontal offset of text */
	int text_size   = 12;				/* size of text font */

	/* Information about the cloud */
	int ovalx1, ovaly1;
	int ovalx2, ovaly2;
	int ovalx3, ovaly3;
	int ovalx4, ovaly4;
	int ovalx5, ovaly5;
	
	/* cloud x, y locations */
	ovalx1 = 180;
	ovaly1 = GP142_YMAX - 60;
	ovalx2 = 145;
	ovaly2 = GP142_YMAX - 30;
	ovalx3 = 110;
	ovaly3 = GP142_YMAX - 60;
	ovalx4 = 165;
	ovaly4 = GP142_YMAX - 15;
	ovalx5 = 125;
	ovaly5 = GP142_YMAX - 40;

	/* Draw the sky */
	GP142_rectangleXY(ICE_BLUE, -GP142_XMAX, -GP142_YMAX,
		GP142_XMAX, GP142_YMAX, FILL);
	
	/* Draw the sun */
	GP142_circleXY(YELLOW, sun_x, sun_y , 20);

	/* Draw the cloud = draw three overlapping ovals */
	GP142_ovalXY(LT_GRAY, ovalx1, ovaly1, ovalx2, ovaly2, FILL);
	GP142_ovalXY(LT_GRAY, ovalx2+10, ovaly2+5, ovalx3, ovaly3, FILL);
	GP142_ovalXY(LT_GRAY, ovalx4, ovaly4, ovalx5, ovaly5, FILL);
	
	/* Draw the ground, highway, road, and text legend */
	GP142_rectangleXY(GREEN, -GP142_XMAX, -GP142_YMAX,
		GP142_XMAX, HORIZON, FILL);
	GP142_rectangleXY(LT_GRAY, 
					-GP142_XMAX, HIGHWAY_CENTER - HIGHWAY_WIDTH,
					 GP142_XMAX, HIGHWAY_CENTER + HIGHWAY_WIDTH,
					 FILL);

	/* Draw a black line down the center of the highway */
	GP142_lineXY(BLACK, -GP142_XMAX, HIGHWAY_CENTER, -XWALK_WIDTH / 2,
		HIGHWAY_CENTER, 1);
	GP142_lineXY(BLACK, XWALK_WIDTH / 2, HIGHWAY_CENTER, GP142_XMAX,
		HIGHWAY_CENTER, 1);

	/* Draw the crosswalk */
	GP142_rectangleXY(BLACK, -XWALK_WIDTH / 2, HIGHWAY_CENTER + HIGHWAY_WIDTH,
		(-XWALK_WIDTH / 2) + 2, HIGHWAY_CENTER - HIGHWAY_WIDTH, FILL);
	GP142_rectangleXY(BLACK, XWALK_WIDTH / 2, HIGHWAY_CENTER + HIGHWAY_WIDTH, 
		(XWALK_WIDTH / 2) + 2, HIGHWAY_CENTER - HIGHWAY_WIDTH, FILL);

	/* print instructions on bottom of window */	
	GP142_printfXY (BLACK, text_offset, -GP142_YMAX+30, text_size,
		"Click a button to control the car or the piggy");
	
	
	/*Draw some mountains */
	GP142_triangleXY(MED_GRAY,
		-GP142_XMAX, HORIZON,
		GP142_XMAX, HORIZON,
		0, (3 * GP142_YMAX)/4 ,
		FILL);
	
	GP142_triangleXY(OLIVE,
		-( 5 * GP142_XMAX/4), HORIZON,
		(GP142_XMAX)/3  , HORIZON,
		-(3* GP142_XMAX)/4, (GP142_YMAX)/2 ,
		FILL);
	
	GP142_triangleXY(FOREST_GREEN,
		-GP142_XMAX / 3 , HORIZON,
		GP142_XMAX, HORIZON,
		GP142_XMAX, (GP142_YMAX)/2,
		FILL);
	
	/* Draw a farmhouse */
	GP142_rectangleXY(DUSTY_PLUM, -GP142_XMAX + 20, HORIZON - 5, -GP142_XMAX + 70,
		HORIZON + 25, FILL);
	GP142_triangleXY(MED_GRAY, -GP142_XMAX + 13, HORIZON + 25, -GP142_XMAX + 77,
		HORIZON + 25, -GP142_XMAX + 45, HORIZON + 43, FILL);
	/* door */
	GP142_rectangleXY(WHITE, -GP142_XMAX + 42, HORIZON - 5, -GP142_XMAX + 48,
		HORIZON + 8, FILL);
	/* windows */
	GP142_rectangleXY(YELLOW, -GP142_XMAX + 35, HORIZON + 18, -GP142_XMAX + 27,
		HORIZON + 12, FILL);
	GP142_rectangleXY(YELLOW, -GP142_XMAX + 63, HORIZON + 18, -GP142_XMAX + 55,
		HORIZON + 12, FILL);

	/* Draw a fence for the piggy */
	/* front horizontal lines */
	GP142_lineXY(BLACK, -GP142_XMAX, HIGHWAY_CENTER + 50, -GP142_XMAX / 2,
		HIGHWAY_CENTER + 50, 1);
	GP142_lineXY(BLACK, -GP142_XMAX, HIGHWAY_CENTER + 40, -GP142_XMAX / 2,
		HIGHWAY_CENTER + 40, 1);
	/* front vertical lines */
	GP142_lineXY(BLACK, -GP142_XMAX + 5, HIGHWAY_CENTER + 52,
		-GP142_XMAX + 5, HIGHWAY_CENTER + 35, 1);
	GP142_lineXY(BLACK, -GP142_XMAX + 42, HIGHWAY_CENTER + 52,
		-GP142_XMAX + 42, HIGHWAY_CENTER + 35, 1);
	GP142_lineXY(BLACK, -GP142_XMAX + 79, HIGHWAY_CENTER + 52,
		-GP142_XMAX + 79, HIGHWAY_CENTER + 35, 1);
	GP142_lineXY(BLACK, -GP142_XMAX + 116, HIGHWAY_CENTER + 52,
		-GP142_XMAX + 116, HIGHWAY_CENTER + 35, 1);
	GP142_lineXY(BLACK, -GP142_XMAX / 2, HIGHWAY_CENTER + 52,
		-GP142_XMAX / 2, HIGHWAY_CENTER + 35, 1);
	/* back horizontal lines */
	GP142_lineXY(BLACK, -GP142_XMAX / 2, HIGHWAY_CENTER + 50,
		(-GP142_XMAX / 2) + 15, HORIZON, 1);
	GP142_lineXY(BLACK, -GP142_XMAX / 2, HIGHWAY_CENTER + 35,
		(-GP142_XMAX / 2) + 16, HORIZON, 1);
	/* GP142_lineXY(BLACK, (-GP142_XMAX / 2) - 2, HIGHWAY_CENTER + 35,
		(-GP142_XMAX / 2) - 2, HORIZON, 1); */




} /*end draw_landscape */





/*****************************************************************************

     BUTTONS AND MOUSE CLICKS

*****************************************************************************/


/* Draws the buttons */
void draw_buttons( )
{
	int i;
	int text_offset = MENU_LEFT+10;	/* offset of button text in button */
	int font_size = 12;				/* size of button text */
	
	/* draw rectangles for each button */
	for(i = 0; i < NUM_BUTTONS; i++) {
		GP142_rectangleXY(BLACK,
			MENU_LEFT,
			MENU_TOP - i * BUTTON_HEIGHT,
			MENU_LEFT + BUTTON_WIDTH,
			MENU_TOP - (i + 1)*BUTTON_HEIGHT, 1);
	}
	
	/* display button text */
	i = MENU_TOP - (BUTTON_HEIGHT/2) - (font_size/2);
	GP142_printfXY(FOREST_GREEN, text_offset, i, font_size, "Go");	
	
	i -= BUTTON_HEIGHT;
	GP142_printfXY(RED, text_offset, i, font_size, "Stop");
	
	i -= BUTTON_HEIGHT;
	GP142_printfXY(BLACK, text_offset, i, font_size, "Faster");
	
	i -= BUTTON_HEIGHT;
	GP142_printfXY(BLACK, text_offset, i, font_size, "Slower");
	
	i -= BUTTON_HEIGHT;
	GP142_printfXY(BLACK, text_offset, i, font_size, "Reverse");
	
	i -= BUTTON_HEIGHT;
	GP142_printfXY(BLACK, text_offset, i, font_size, "New Color");

	i -= BUTTON_HEIGHT;
	GP142_printfXY(BLACK, text_offset, i, font_size, "Free Piggy!");
	
}

/* Classify mouse click at (mouse_x,mouse_y) and return kind */
int  classify_mouse_click(int mouse_x, int mouse_y)
{
	if ((mouse_x > MENU_LEFT) &&
		(mouse_x < MENU_LEFT + BUTTON_WIDTH) &&
		(mouse_y < MENU_TOP) &&
		(mouse_y > (MENU_TOP - NUM_BUTTONS*BUTTON_HEIGHT)))
		return BUTTON_CLICK;
	else
		return OTHER_CLICK;
}



/* Process button click at location x, y.  Update pig location,	*/
/* car speed, direction, color, and whether traffic is moving as needed. */
void handle_button(int x, int y, int *traffic_moving, int *car_speed,
				   int car_direction[], int car_color[], int *freepiggy)
{
	int buttonNum;		/* number of selected button */
	int i;				/* array element */

	/* Complain if x coordinate couldn't be inside a button */
	if (x < MENU_LEFT || x > MENU_LEFT + BUTTON_WIDTH) {
		something_is_wrong();
		return;
	}
	
	/* Convert y coordinate to button number from top. */
	buttonNum = (MENU_TOP - y)/BUTTON_HEIGHT;	 
	


	switch(buttonNum) {
	case 0:
		/* go */
		*traffic_moving = TRUE;
		break;
	case 1:
		/* stop */
		*traffic_moving = FALSE;
		break;
		
	case 2:
		/* speed up */
		*car_speed = *car_speed + 1;
		break;
	case 3:
		/* slow down */
		*car_speed = *car_speed - 1;
		if (*car_speed < 0)
			*car_speed = 0;
		break;
		
	case 4:
		/* reverse */
		for (i = 0; i < 4; i++){
			car_direction[i] = - car_direction[i];
		}
		break;
	case 5:
		/* change car color */
		for (i = 0; i < 4; i++){
			car_color[i] = (car_color[i]+1) % MAX_COLORS;
		}
		break;
	case 6:
		/* free the piggy */
		*freepiggy = TRUE;
		break;
	default:
		/*Bad news if this is ever reached! */
		something_is_wrong();
		break;
	}
}



/*****************************************************************************

     TRAFFIC AND OTHER ANIMATED OBJECTS

*****************************************************************************/


/* Update sun coordinates sun_x, sun_y by one tick */
void move_sun(int *sun_x, int *sun_y) {
	/* Move the sun to the left.  If it reaches the edge, move it */
	/* to the other side and down a bit. */
	(*sun_x) --;
	if (*sun_x < -GP142_XMAX -30) {
		*sun_x = - *sun_x;
		(*sun_y) --;
	}
}


/* Update all vehicle x, y coordinates, given current x, y */
/* location, direction (+1 or -1), and speed in pixels per tick, */
void move_traffic(int x[], int y[], int direction[], int speed) {
	/* Note: If there is more than one vehicle, this should */
	/* be updated to adjust all vehicle coordinates */

	int trial_x;		/* new value for x coordinate */
	int i;				/* array element */

	for(i = 0; i < 4; i++) {
		/* move vehicle.  If it moves off the edge, start it again
		* on the other side */
		trial_x = x[i] + (direction[i] * speed);
		if (abs(trial_x) > GP142_XMAX + CAR_WIDTH/2)
			x[i] = -trial_x;		/* make car go to other side of screen */
		else
			x[i] = trial_x;
	}
}


/* Draw all vehicles given their current x, y coordinates and color */
void draw_traffic(int x[], int y[], int color[]) {
	/* Note: needs to be changed if there is more than */
	/* one vehicle */
	draw_car(x,y,color);
}



/* Draw the cars of the given color with horizontal */
/* center x and bottom y */
void draw_car(int x[], int y[], int color[]) {

	int i;			/* array element */

	for(i = 0; i < 4; i++){

		GP142_rectangleXY(color[i], x[i] - CAR_WIDTH/2, y[i] + CAR_HEIGHT/4,
						x[i] + CAR_WIDTH/2, y[i] + CAR_HEIGHT*3/4, FILL);
		GP142_rectangleXY(color[i], x[i] - CAR_WIDTH/6, y[i] + CAR_HEIGHT*3/4,
						x[i] + CAR_WIDTH/6, y[i] + CAR_HEIGHT, FILL);
		GP142_circleXY(BLACK, x[i] - CAR_WIDTH/4, y[i] + CAR_HEIGHT/4, CAR_HEIGHT/4);
		GP142_circleXY(BLACK, x[i] + CAR_WIDTH/4, y[i] + CAR_HEIGHT/4, CAR_HEIGHT/4);
	}
}	


/* Move the piggy along it's path according to pig_step */
void Move_piggy(int *pig_x, int *pig_y, int *pig_time, int *freepiggy) {

	/* These arrays contain the number of pixels that pig_x and pig_y
	 * change at each step in the path of the pig when it is freed. */
	int step_x[] = {15, 20, 20, 20, 20, 10, 10, 10, 10, 10, 10, 10, 10, 
		10, 10, 10, -25, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
		0, 0, 0, 0, 0, 0, 0, 15, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
		10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
		10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 10, 
		10, 10, 10, 10, 10, 10, 10, 10};
	int step_y[] = {0, 20, 20, -20, -20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
		-20, -6, -6, -6, -6, -6, -6, -6, -6, -6, -6, -6, -6, -6, -6, -6, 
		-6, -6, -6, -6, -6, -6, -6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
	/* get number of array elements */
	int timestop = sizeof(step_x) / sizeof(int);

	/* update pig x, y locations */
	*pig_x = *pig_x + step_x[*pig_time];
	*pig_y = *pig_y + step_y[*pig_time];

	/* when pig moves off the screen, have another pig walk on 
	 * the other side and assume the original pig location */
	if (*pig_time == 73) {
		*pig_x = -*pig_x;
		*pig_y = HIGHWAY_CENTER / 3;
	}
	
	/* when the end of the pig path is reached, make sure pig
	 * is in the right place and reset freepiggy and pig_time */
	if (++(*pig_time) >= timestop) {
		*pig_x = -GP142_XMAX + 120;
		*freepiggy = FALSE;
		*pig_time = 0;

	}
}





void
Draw_piggy(int x, int y, int pig_time)
{
	if ((pig_time > 16) && (pig_time < 40)) {
		/* if time for piggy to turn and face forward, draw
		 * forward facing piggy */
		GP142_circleXY(PINK, x, y, 9);
		GP142_triangleXY(PINK, x - 7, y + 7, x - 1, y + 7, x - 6, 
			y + 14, FILL);
		GP142_triangleXY(PINK, x + 7, y + 7, x + 1, y + 7, x + 6,
			y + 14, FILL);
		GP142_ovalXY(BLACK, x + 3, y, x - 3, y - 5, 1);
		GP142_circleXY(BLACK, x + 4, y + 3, 1);
		GP142_circleXY(BLACK, x - 4, y + 3, 1);
		GP142_ovalXY(PINK, x - 10, y - 8, x + 10, y - 23, FILL);
		GP142_lineXY(PINK, x - 6, y - 20, x - 9, y - 30, 2);
		GP142_lineXY(PINK, x + 6, y - 20, x + 9, y - 30, 2);


		

	}

	/* else draw normal side facing pig */
	else {

		GP142_circleXY(PINK, x, y, 9);
		GP142_circleXY(BLACK, x + 3, y + 3, 1);
		GP142_rectangleXY(PINK, x, y + 2, x + 13, y - 4, FILL);
		GP142_triangleXY(PINK, x - 3, y + 8, x + 3, y + 8, x, y + 14, FILL);
		GP142_ovalXY(PINK, x - 5, y + 2, x - 40, y - 18, FILL);
		GP142_lineXY(PINK, x - 35, y - 6, x - 43, y - 1, 2);
		GP142_lineXY(PINK, x - 35, y - 15, x - 37, y - 25, 2);
		GP142_lineXY(PINK, x - 31, y - 15, x - 30, y - 25, 2);
		GP142_lineXY(PINK, x - 10, y - 15, x - 12, y - 25, 2);
		GP142_lineXY(PINK, x - 8, y - 15, x - 6, y - 25, 2);
	}

}
/* 


/*****************************************************************************

     OTHER

*****************************************************************************/


/* Initialize random number generator */
/* [Ignore or delete if your program  */
/* doesn't user random numbers.] */
void initialize_random_numbers() {
	time_t t;			/* current time */
	srand (time(&t));
}



/* Display error message if internal error is detected. */
void something_is_wrong (void) {
	GP142_printfXY (RED, 0, 0, 16, "BAAAADDD NEWS!");
}